[autotest] Exclude moblab from lab inventory management.

The moblab instances in Stierlin Ct are handled by a separate
process that's separate from the standard lab inventory cron job
e-mail.  So, remove the board from consideration.

BUG=chromium:757815
TEST=unit test for sanity

Change-Id: Ie327752c2b2980f541e091867e75ac135f870e83
Reviewed-on: https://chromium-review.googlesource.com/647316
Commit-Ready: Richard Barnette <jrbarnette@chromium.org>
Tested-by: Richard Barnette <jrbarnette@chromium.org>
Reviewed-by: Richard Barnette <jrbarnette@google.com>
diff --git a/site_utils/lab_inventory.py b/site_utils/lab_inventory.py
index c00d199..b52327e 100755
--- a/site_utils/lab_inventory.py
+++ b/site_utils/lab_inventory.py
@@ -69,11 +69,12 @@
 MANAGED_POOLS = constants.Pools.MANAGED_POOLS
 
 # _EXCLUDED_LABELS - A set of labels that disqualify a DUT from
 #     monitoring by this script.  Currently, we're excluding any
 #     'adb' host, because we're not ready to monitor Android or
 #     Brillo hosts.
 
-_EXCLUDED_LABELS = set(['adb'])
+_EXCLUDED_LABELS = {'adb', 'board:guado_moblab'}
 
 # _DEFAULT_DURATION:
 #     Default value used for the --duration command line option.
@@ -69,11 +69,12 @@
 
 # _EXCLUDED_LABELS - A set of labels that disqualify a DUT from
-#     monitoring by this script.  Currently, we're excluding any
-#     'adb' host, because we're not ready to monitor Android or
-#     Brillo hosts.
+#     monitoring by this script.  Currently, we're excluding these:
+#   + 'adb' - We're not ready to monitor Android or Brillo hosts.
+#   + 'board:guado_moblab' - These are maintained by a separate
+#     process that doesn't use this script.
 